#!/bin/sh
#
# (C) COPYRIGHT TIVOLI Systems, Inc. 2002
# Unpublished/Unverified Work
# All Rights Reserved
# Licensed Material - Property of TIVOLI Systems, Inc.
#

# -----------------------------------------------------------------------------------
# Script Name: tmo_patch_0011.sh
#
# Usage:
# 
# Upon the installation of 2.0-ORA-0012, 'tmo_patch_0012.sh' needs to be run on the 
# TMR server.
# 
# The 'tmo_patch_0012.sh' script does the following:
# 1. Synchronizes all the gateways in the local TMR with the defined dependencies
# 2. Ensures all the required binaries are downloaded to the LCF endpoints where
#    the managed Oracle databases reside. 
# 3. Makes a backup of the DSMF Controller lists.
# 4. Initiates the update of the DSMF Controller lists. This is to ensure that 
#    the version-specific 'OracleSQLEngine(7/8)' are used subsequently. 
#
# Notes:
#
#  - 'tmo_patch_0011.sh' only needs to be run on the TMR server.
#  - Because new files may need to be downloaded to the LCF endpoint, 
#    'tmo_patch_0011.sh' might take a while to run.
#  - Make sure your environment is setup prior to running 'tmo_patch_0011.sh'
#    by running 'setup_env.sh'.
# -----------------------------------------------------------------------------------

if [ -z "$BINDIR" ]
then
    echo "\nThe \"setup_env.sh\" script must be run prior to executing \"$0\".\n"
    exit 1
fi

TMRNAME=`wtmrname`

echo "\nRunning \"$0\" on the \"$TMRNAME\" TMR.\n"

OSERV=`objcall 0.0.0 get_oserv`
INSTALL_DIR=`objcall $OSERV query install_dir`
INSTALL_DIR=`echo $INSTALL_DIR | tr '\\\' '/'`
INTERP=`objcall $OSERV query interp`
BINDIR=$INSTALL_DIR/$INTERP

TIMESTAMP=`date +%Y.%m.%d.%H.%M`

echo "Synchronizing gateways with dependencies, please wait ...\n"
# Synchronize all local gateways with new dependencies

wls /Library/Gateway |
while read GW_LABEL
do
    #echo "gateway = $GW_LABEL"
    wgateway "$GW_LABEL#$TMRNAME" dbcheck > /dev/null
done

# Fixup DSMF depset

dsmf_depset_out=`$BINDIR/../generic_unix/TME/DSMF/DSMF.depset.sh 2> /dev/null`

# Now lets call 'InitializeEndpoint' and get our files to the LCF endpoint ....
OBJECTCLASS=OracleInstanceManager

wls -o /Library/$OBJECTCLASS |
while read OID LABEL
do
    idlcall $OID InitializeEndpoint > /dev/null

done

# ----------------------------------------
# Shutdown DSMFController
#
echo "Shutting down DSMF Controller, please wait ...\n"
ODLINE=`odstat -d | grep DSMFController`

kill_command="kill"
kill_flag="-9"

if [ "$INTERP" = "w32-ix86" ]; then
    kill_command="ntprocinfo -k"
    kill_flag=""
fi


if [ $? -eq 0 ]; then
    DPID=`echo "$ODLINE" | awk '{print $1}'`

    #echo "PID = $DPID"

    $kill_command $DPID 2> /dev/null

    # If it didnt die then use a bit more force
    #
    sleep 2
    ODLINE=`odstat -d | grep DSMFController`
    if [ $? -eq 0 ]; then
        $kill_command $kill_flag $DPID > /dev/null
    fi

fi

echo "DSMF Controller shutdown completed.\n"

#----------------------------------------
# Backup DSMF attributes
#

echo "Backing up DSMF configuration, please wait ...\n"
CONT=`wlookup -r distinguished DSMFController`

idlattr -tg $CONT Agents DSMF::AgentList > "$DBDIR"/DSMF_AgentList.out.$TIMESTAMP
idlattr -tg $CONT Instances DSMF::InstanceList > "$DBDIR"/DSMF_InstanceList.out.$TIMESTAMP
idlattr -tg $CONT Behaviours DSMF::BehaviourList > "$DBDIR"/DSMF_BehaviourList.out.$TIMESTAMP

echo "DSMF configuration backed up in: "$DBDIR"\n"

#----------------------------------------
# Perform dbcheck to update DSMF
#
echo "Updating DSMF configuration, please wait ...\n"

DSMFCONT=`echo "$CONT" | awk -F# '{print $1}'`

idlcall $DSMFCONT DbCheck > /dev/null

echo "DSMF configuration update completed.\n"

echo "Done running \"$0\" on the \"$TMRNAME\" TMR.\n"

exit 0


